@@ -1,13 +1,15 @@
 from quickbuild.adapters.aio import AsyncQBClient
 from quickbuild.adapters.sync import QBClient
-from quickbuild.exceptions import QuickBuildError
+from quickbuild.exceptions import QBError, QBNotFoundError, QBProcessingError
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 
 __all__ = (
     # adapters
     'AsyncQBClient',
     'QBClient',
     # exceptions
-    'QuickBuildError',
+    'QBError',
+    'QBNotFoundError',
+    'QBProcessingError',
 )
